@@ -39,7 +39,7 @@ from .evaluators._spec import EvaluatorSpec
 from .evaluators.common import DEFAULT_EVALUATORS
 from .evaluators.context import EvaluatorContext
 from .otel import SpanTree
-from .otel._context_in_memory_span_exporter import context_subtree
+from .otel._context_subtree import context_subtree
 from .reporting import EvaluationReport, ReportCase
 
 if sys.version_info < (3, 11):  # pragma: no cover
@@ -388,9 +388,9 @@ class Dataset(BaseModel, Generic[InputsT, OutputT, MetadataT], extra='forbid', a
                 return args
         else:  # pragma: no cover
             warnings.warn(
-                f'Could not determine the generic parameters for {cls}; using `Any` for each. '
-                f'You should explicitly set the generic parameters via `Dataset[MyInputs, MyOutput, MyMetadata]`'
-                f'when serializing or deserializing.',
+                f'Could not determine the generic parameters for {cls}; using `Any` for each.'
+                f' You should explicitly set the generic parameters via `Dataset[MyInputs, MyOutput, MyMetadata]`'
+                f' when serializing or deserializing.',
                 UserWarning,
             )
             return Any, Any, Any  # type: ignore
@@ -873,7 +873,7 @@ async def _run_task_and_evaluators(
     with _logfire.span(
         'case: {case_name}',
         task_name=get_unwrapped_function_name(task),
-        case_name=case.name,
+        case_name=report_case_name,
         inputs=case.inputs,
         metadata=case.metadata,
         expected_output=case.expected_output,
@@ -1069,7 +1069,8 @@ def _load_evaluator_from_registry(
     evaluator_class = registry.get(spec.name)
     if evaluator_class is None:
         raise ValueError(
-            f'Evaluator {spec.name!r} is not in the provided registry. Registered choices: {list(registry.keys())}'
+            f'Evaluator {spec.name!r} is not in the provided `custom_evaluator_types`. Valid choices: {list(registry.keys())}.'
+            f' If you are trying to use a custom evaluator, you must include its type in the `custom_evaluator_types` argument.'
         )
     try:
         return evaluator_class(*spec.args, **spec.kwargs)
