@@ -8,7 +8,10 @@ from pydantic_core import to_json
 
 from pydantic_ai import Agent, models
 
-__all__ = ('GradingOutput', 'judge_input_output', 'judge_output')
+__all__ = ('GradingOutput', 'judge_input_output', 'judge_output', 'set_default_judge_model')
+
+
+_default_model: models.Model | models.KnownModelName = 'openai:gpt-4o'
 
 
 class GradingOutput(BaseModel, populate_by_name=True):
@@ -36,16 +39,20 @@ _judge_output_agent = Agent(
         {"reason": "'avast ye' is a common pirate term", "pass": false, "score": 0.0}
         """
     ),
-    result_type=GradingOutput,
+    output_type=GradingOutput,
 )
 
 
 async def judge_output(
-    output: Any, rubric: str, model: models.Model | models.KnownModelName = 'openai:gpt-4o'
+    output: Any, rubric: str, model: models.Model | models.KnownModelName | None = None
 ) -> GradingOutput:
-    """Judge the output of a model based on a rubric."""
+    """Judge the output of a model based on a rubric.
+
+    If the model is not specified, a default model is used. The default model starts as 'openai:gpt-4o',
+    but this can be changed using the `set_default_judge_model` function.
+    """
     user_prompt = f'<Output>\n{_stringify(output)}\n</Output>\n<Rubric>\n{rubric}\n</Rubric>'
-    return (await _judge_output_agent.run(user_prompt, model=model)).data
+    return (await _judge_output_agent.run(user_prompt, model=model or _default_model)).output
 
 
 _judge_input_output_agent = Agent(
@@ -67,16 +74,29 @@ _judge_input_output_agent = Agent(
         {"reason": "'avast ye' is a common pirate term", "pass": false, "score": 0.0}
         """
     ),
-    result_type=GradingOutput,
+    output_type=GradingOutput,
 )
 
 
 async def judge_input_output(
-    inputs: Any, output: Any, rubric: str, model: models.Model | models.KnownModelName = 'openai:gpt-4o'
+    inputs: Any, output: Any, rubric: str, model: models.Model | models.KnownModelName | None = None
 ) -> GradingOutput:
-    """Judge the output of a model based on the inputs and a rubric."""
+    """Judge the output of a model based on the inputs and a rubric.
+
+    If the model is not specified, a default model is used. The default model starts as 'openai:gpt-4o',
+    but this can be changed using the `set_default_judge_model` function.
+    """
     user_prompt = f'<Input>\n{_stringify(inputs)}\n</Input>\n<Output>\n{_stringify(output)}\n</Output>\n<Rubric>\n{rubric}\n</Rubric>'
-    return (await _judge_input_output_agent.run(user_prompt, model=model)).data
+    return (await _judge_input_output_agent.run(user_prompt, model=model or _default_model)).output
+
+
+def set_default_judge_model(model: models.Model | models.KnownModelName) -> None:  # pragma: no cover
+    """Set the default model used for judging.
+
+    This model is used if `None` is passed to the `model` argument of `judge_output` and `judge_input_output`.
+    """
+    global _default_model
+    _default_model = model
 
 
 def _stringify(value: Any) -> str:
